<?php


/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 584;

/**
 * Tell WordPress to run twentyeleven_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'twentyeleven_setup' );

if ( ! function_exists( 'twentyeleven_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * To override twentyeleven_setup() in a child theme, add your own twentyeleven_setup to your child theme's
 * functions.php file.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To style the visual editor.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links, custom headers
 * 	and backgrounds, and post formats.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses register_default_headers() To register the default custom header images provided with the theme.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since Twenty Eleven 1.0
 */
function twentyeleven_setup() {

	/* Make Twenty Eleven available for translation.
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on Twenty Eleven, use a find and replace
	 * to change 'twentyeleven' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'twentyeleven', get_template_directory() . '/languages' );

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// Load up our theme options page and related code.
	require( get_template_directory() . '/inc/theme-options.php' );

	// Grab Twenty Eleven's Ephemera widget.
	require( get_template_directory() . '/inc/widgets.php' );

	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'twentyeleven' ) );

	// Add support for a variety of post formats
	add_theme_support( 'post-formats', array( 'aside', 'link', 'gallery', 'status', 'quote', 'image' ) );

	$theme_options = twentyeleven_get_theme_options();
	if ( 'dark' == $theme_options['color_scheme'] )
		$default_background_color = '1d1d1d';
	else
		$default_background_color = 'f1f1f1';

	// Add support for custom backgrounds.
	add_theme_support( 'custom-background', array(
		// Let WordPress know what our default background color is.
		// This is dependent on our current color scheme.
		'default-color' => $default_background_color,
	) );

	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );

	// Add support for custom headers.
	$custom_header_support = array(
		// The default header text color.
		'default-text-color' => '000',
		// The height and width of our custom header.
		'width' => apply_filters( 'twentyeleven_header_image_width', 1000 ),
		'height' => apply_filters( 'twentyeleven_header_image_height', 288 ),
		// Support flexible heights.
		'flex-height' => true,
		// Random image rotation by default.
		'random-default' => true,
		// Callback for styling the header.
		'wp-head-callback' => 'twentyeleven_header_style',
		// Callback for styling the header preview in the admin.
		'admin-head-callback' => 'twentyeleven_admin_header_style',
		// Callback used to display the header preview in the admin.
		'admin-preview-callback' => 'twentyeleven_admin_header_image',
	);
	
	add_theme_support( 'custom-header', $custom_header_support );

	if ( ! function_exists( 'get_custom_header' ) ) {
		// This is all for compatibility with versions of WordPress prior to 3.4.
		define( 'HEADER_TEXTCOLOR', $custom_header_support['default-text-color'] );
		define( 'HEADER_IMAGE', '' );
		define( 'HEADER_IMAGE_WIDTH', $custom_header_support['width'] );
		define( 'HEADER_IMAGE_HEIGHT', $custom_header_support['height'] );
		add_custom_image_header( $custom_header_support['wp-head-callback'], $custom_header_support['admin-head-callback'], $custom_header_support['admin-preview-callback'] );
		add_custom_background();
	}

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be the size of the header image that we just defined
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( $custom_header_support['width'], $custom_header_support['height'], true );

	// Add Twenty Eleven's custom image sizes.
	// Used for large feature (header) images.
	add_image_size( 'large-feature', $custom_header_support['width'], $custom_header_support['height'], true );
	// Used for featured posts if a large-feature doesn't exist.
	add_image_size( 'small-feature', 500, 300 );

	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
		'wheel' => array(
			'url' => '%s/images/headers/wheel.jpg',
			'thumbnail_url' => '%s/images/headers/wheel-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Wheel', 'twentyeleven' )
		),
		'shore' => array(
			'url' => '%s/images/headers/shore.jpg',
			'thumbnail_url' => '%s/images/headers/shore-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Shore', 'twentyeleven' )
		),
		'trolley' => array(
			'url' => '%s/images/headers/trolley.jpg',
			'thumbnail_url' => '%s/images/headers/trolley-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Trolley', 'twentyeleven' )
		),
		'pine-cone' => array(
			'url' => '%s/images/headers/pine-cone.jpg',
			'thumbnail_url' => '%s/images/headers/pine-cone-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Pine Cone', 'twentyeleven' )
		),
		'chessboard' => array(
			'url' => '%s/images/headers/chessboard.jpg',
			'thumbnail_url' => '%s/images/headers/chessboard-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Chessboard', 'twentyeleven' )
		),
		'lanterns' => array(
			'url' => '%s/images/headers/lanterns.jpg',
			'thumbnail_url' => '%s/images/headers/lanterns-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Lanterns', 'twentyeleven' )
		),
		'willow' => array(
			'url' => '%s/images/headers/willow.jpg',
			'thumbnail_url' => '%s/images/headers/willow-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Willow', 'twentyeleven' )
		),
		'hanoi' => array(
			'url' => '%s/images/headers/hanoi.jpg',
			'thumbnail_url' => '%s/images/headers/hanoi-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'Hanoi Plant', 'twentyeleven' )
		)
	) );
}
endif; // twentyeleven_setup

if ( ! function_exists( 'twentyeleven_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @since Twenty Eleven 1.0
 */
function twentyeleven_header_style() {
	$text_color = get_header_textcolor();

	// If no custom options for text are set, let's bail.
	if ( $text_color == HEADER_TEXTCOLOR )
		return;
		
	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == $text_color ) :
	?>
		#site-title,
		#site-description {
			position: absolute !important;
			clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		#site-title a,
		#site-description {
			color: #<?php echo $text_color; ?> !important;
		}
		.entry-title a{ border-bottom:dashed 1px #<?php echo get_header_textcolor(); ?>;
					border-left:groove 5px #<?php echo get_header_textcolor(); ?>; }
		.entry-title_screen{border-bottom: 1px dashed #<?php echo get_header_textcolor(); ?>;
    border-left: 5px groove #<?php echo get_header_textcolor(); ?>;}
		.side_gun{ border-left: double 5px #<?php echo get_header_textcolor(); ?>;}
	<?php endif; ?>
	</style>
	<?php
}
endif; // twentyeleven_header_style

if ( ! function_exists( 'twentyeleven_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * Referenced via add_theme_support('custom-header') in twentyeleven_setup().
 *
 * @since Twenty Eleven 1.0
 */
function twentyeleven_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}
	#headimg h1,
	#desc {
		font-family: "Helvetica Neue", Arial, Helvetica, "Nimbus Sans L", sans-serif;
	}
	#headimg h1 {
		margin: 0;
	}
	#headimg h1 a {
		font-size: 32px;
		line-height: 36px;
		text-decoration: none;
	}
	#desc {
		font-size: 14px;
		line-height: 23px;
		padding: 0 0 3em;
	}
	<?php
		// If the user has set a custom color for the text use that
		if ( get_header_textcolor() != HEADER_TEXTCOLOR ) :
	?>
		#site-title a,
		#site-description {
			color: #<?php echo get_header_textcolor(); ?>;
		}
	.entry-title a{ border-bottom:dashed 1px #<?php echo get_header_textcolor(); ?>;
					border-left:groove 5px #<?php echo get_header_textcolor(); ?>; }
	<?php endif; ?>
	#headimg img {
		max-width: 1000px;
		height: auto;
		width: 100%;
	}
	</style>
<?php
}
endif; // twentyeleven_admin_header_style

if ( ! function_exists( 'twentyeleven_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * Referenced via add_theme_support('custom-header') in twentyeleven_setup().
 *
 * @since Twenty Eleven 1.0
 */
function twentyeleven_admin_header_image() { ?>
	<div id="headimg">
		<?php
		$color = get_header_textcolor();
		$image = get_header_image();
		if ( $color && $color != 'blank' )
			$style = ' style="color:#' . $color . '"';
		else
			$style = ' style="display:none"';
		?>
		<h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php if ( $image ) : ?>
			<img src="<?php echo esc_url( $image ); ?>" alt="" />
		<?php endif; ?>
	</div>
<?php }
endif; // twentyeleven_admin_header_image

/**
 * Sets the post excerpt length to 40 words.
 *
 * To override this length in a child theme, remove the filter and add your own
 * function tied to the excerpt_length filter hook.
 */
function twentyeleven_excerpt_length( $length ) {
	return 40;
}
add_filter( 'excerpt_length', 'twentyeleven_excerpt_length' );

/**
 * Returns a "Continue Reading" link for excerpts
 */
function twentyeleven_continue_reading_link() {
	return ' <a href="'. esc_url( get_permalink() ) . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'twentyeleven' ) . '</a>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and twentyeleven_continue_reading_link().
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 */
function twentyeleven_auto_excerpt_more( $more ) {
	return ' &hellip;' . twentyeleven_continue_reading_link();
}
add_filter( 'excerpt_more', 'twentyeleven_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_the_excerpt filter hook.
 */
function twentyeleven_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= twentyeleven_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'twentyeleven_custom_excerpt_more' );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function twentyeleven_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'twentyeleven_page_menu_args' );

/**
 * Register our sidebars and widgetized areas. Also register the default Epherma widget.
 *
 * @since Twenty Eleven 1.0
 */
function twentyeleven_widgets_init() {

	register_widget( 'Twenty_Eleven_Ephemera_Widget' );

	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'twentyeleven' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Showcase Sidebar', 'twentyeleven' ),
		'id' => 'sidebar-2',
		'description' => __( 'The sidebar for the optional Showcase Template', 'twentyeleven' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area One', 'twentyeleven' ),
		'id' => 'sidebar-3',
		'description' => __( 'An optional widget area for your site footer', 'twentyeleven' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area Two', 'twentyeleven' ),
		'id' => 'sidebar-4',
		'description' => __( 'An optional widget area for your site footer', 'twentyeleven' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area Three', 'twentyeleven' ),
		'id' => 'sidebar-5',
		'description' => __( 'An optional widget area for your site footer', 'twentyeleven' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'twentyeleven_widgets_init' );

if ( ! function_exists( 'twentyeleven_content_nav' ) ) :
/**
 * Display navigation to next/previous pages when applicable
 */
function twentyeleven_content_nav( $nav_id ) {
	global $wp_query;

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $nav_id; ?>">
			<h3 class="assistive-text"><?php _e( 'Post navigation', 'twentyeleven' ); ?></h3>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> 前へ', 'twentyeleven' ) ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( '次へ <span class="meta-nav">&rarr;</span>', 'twentyeleven' ) ); ?></div>
		</nav><!-- #nav-above -->
	<?php endif;
}
endif; // twentyeleven_content_nav

/**
 * Return the URL for the first link found in the post content.
 *
 * @since Twenty Eleven 1.0
 * @return string|bool URL or false when no link is present.
 */
function twentyeleven_url_grabber() {
	if ( ! preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', get_the_content(), $matches ) )
		return false;

	return esc_url_raw( $matches[1] );
}

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 */
function twentyeleven_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-3' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-4' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-5' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
	}

	if ( $class )
		echo 'class="' . $class . '"';
}

if ( ! function_exists( 'twentyeleven_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own twentyeleven_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Twenty Eleven 1.0
 */
function twentyeleven_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'twentyeleven' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'twentyeleven' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-meta">
				<div class="comment-author vcard">
					<?php
						$avatar_size = 68;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

						echo get_avatar( $comment, $avatar_size );

						/* translators: 1: comment author, 2: date and time */
						printf( __( '%1$s on %2$s <span class="says">said:</span>', 'twentyeleven' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'twentyeleven' ), get_comment_date(), get_comment_time() )
							)
						);
					?>

					<?php edit_comment_link( __( 'Edit', 'twentyeleven' ), '<span class="edit-link">', '</span>' ); ?>
				</div><!-- .comment-author .vcard -->

				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'twentyeleven' ); ?></em>
					<br />
				<?php endif; ?>

			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'twentyeleven' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif; // ends check for twentyeleven_comment()

if ( ! function_exists( 'twentyeleven_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own twentyeleven_posted_on to override in a child theme
 *
 * @since Twenty Eleven 1.0
 */
function twentyeleven_posted_on() {
	printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a><span class="by-author"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'twentyeleven' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'twentyeleven' ), get_the_author() ) ),
		get_the_author()
	);
}
endif;

/**
 * Adds two classes to the array of body classes.
 * The first is if the site has only had one author with published posts.
 * The second is if a singular post being displayed
 *
 * @since Twenty Eleven 1.0
 */
function twentyeleven_body_classes( $classes ) {

	if ( function_exists( 'is_multi_author' ) && ! is_multi_author() )
		$classes[] = 'single-author';

	if ( is_singular() && ! is_home() && ! is_page_template( 'showcase.php' ) && ! is_page_template( 'sidebar-page.php' ) )
		$classes[] = 'singular';

	return $classes;
}
add_filter( 'body_class', 'twentyeleven_body_classes' );


//カスタムポストタイプ設定

/*賃貸不動産用投稿タイプ*/




add_action('init', 'add_realestate_type');
function add_realestate_type() {
 register_post_type('realestate', $args = array(
    'label' => '物件',
    'labels' => array(
      'singular_name' => '物件',
      'add_new_item' => '新規物件を追加',
      'add_new' => '新規追加',
      'new_item' => '新規物件',
      'view_item' => '物件を表示',
      'not_found' => '物件は見つかりませんでした',
      'not_found_in_trash' => 'ゴミ箱に物件はありません。',
      'search_items' => '物件を検索',
    ),
    'public' => true,
    'show_ui' => true, 
    'query_var' => true,
    'capability_type' => 'post',
    'hierarchical' => false,
    'menu_position' => 5,
    'supports' => array('title','editor','author','thumbnail',
                                    'excerpt','comments','custom-fields'),
'register_meta_box_cb'=>'room_meta_box'
  ) 
  );

  $args = array(
    'label' => '地域',
    'labels' => array(
      'name' => '地域',
      'singular_name' => '地域',
      'search_items' => '地域を検索',
      'popular_items' => 'よく使われている地域',
      'all_items' => 'すべての地域',
      'parent_item' => '親地域',
      'edit_item' => '地域の編集',
      'update_item' => '更新',
      'add_new_item' => '新規地域を追加',
      'new_item_name' => '新しい地域',
    ),
    'public' => true,
    'show_ui' => true,
    'hierarchical' => true,
  );
  register_taxonomy('area', 'realestate', $args);

  
  $args = array(
    'label' => 'PRタグ',
    'labels' => array(
      'name' => 'PRタグ',
      'singular_name' => 'PRタグ',
      'search_items' => 'PRタグを検索',
      'popular_items' => 'よく使われているPRタグ',
      'all_items' => 'すべてのPRタグ',
      'edit_item' => 'PRタグの編集',
      'update_item' => '更新',
      'add_new_item' => '新規PRタグを追加',
      'new_item_name' => '新しいPRタグ',
      'choose_from_most_used' => 'よく使われているPRタグから選択'
    ),
    'public' => true,
    'show_ui' => true,
    'hierarchical' => false,
    'show_tagcloud' => true
  );
  register_taxonomy('prtag', 'realestate', $args);
 
  
}


function room_meta_box($post){
	add_meta_box('menu_meta','賃貸情報','menu_meta_html','realestate','normal','high');
	}
	
	function menu_meta_html($post,$box){
	
	$price=get_post_meta($post->ID,'price',true);
	$madori=get_post_meta($post->ID,'madori',true);
	$sikikin=get_post_meta($post->ID,'sikikin',true);
	$reikin=get_post_meta($post->ID,'reikin',true);
	$menseki=get_post_meta($post->ID,'menseki',true);
	$park=get_post_meta($post->ID,'park',true);
	$address=get_post_meta($post->ID,'address',true);
	$setubi=get_post_meta($post->ID,'setubi',true);
	$come=get_post_meta($post->ID,'come',true);
	$keid=get_post_meta($post->ID,'keid',true);
	$ido=get_post_meta($post->ID,'ido',true);
	echo wp_nonce_field('menu_meta','menu_meta_nonce');
	
	echo '<p>賃料：<input type="text" size="50" name="price" value="'.$price.'">(半角数字、カンマ 円マーク不要)</p>';
	echo '<p>間取り';
	
	?>
	<select name="madori">
    <option <?php if($madori=="1R"){?>selected="selected"<?php } ?>>1R</option>
     <option <?php if($madori=="1K"){?>selected="selected"<?php } ?>>1K</option>
      <option <?php if($madori=="1DK"){?>selected="selected"<?php } ?>>1DK</option>
       <option <?php if($madori=="1LDK"){?>selected="selected"<?php } ?>>1LDK</option>
        <option <?php if($madori=="2K"){?>selected="selected"<?php } ?>>2K</option>
         <option <?php if($madori=="2DK"){?>selected="selected"<?php } ?>>2DK</option>
          <option <?php if($madori=="2LDK"){?>selected="selected"<?php } ?>>2LDK</option>
           <option <?php if($madori=="3DK"){?>selected="selected"<?php } ?>>3DK</option>
            <option <?php if($madori=="3LDK"){?>selected="selected"<?php } ?>>3LDK</option>
             <option <?php if($madori=="一戸建て"){?>selected="selected"<?php } ?>>一戸建て</option>
    </select>
	</p>
	<?php
	echo '<p>敷金：<input type="text" size="50" name="sikikin" value="'.$sikikin.'">(半角数字、要カンマ)</p>';
	echo '<p>礼金：<input type="text" size="50" name="reikin" value="'.$reikin.'">(数字は半角、要カンマ)</p>';
	echo '<p>面積：<input type="text" size="50" name="menseki" value="'.$menseki.'">(数字は半角、要カンマ、要単位)</p>';
	echo '<p>駐車場：<input type="text" size="50" name="park" value="'.$park.'">(数字は半角、要カンマ,円マーク)</p>';
	echo '<p>住所：<input type="text" size="60" name="address" value="'.$address.'"></p>';
	echo '<p>設備：<input type="text" size="60" name="setubi" value="'.$setubi.'"></p>';
	echo '<p>コメント：<input type="text" size="50" name="come" value="'.$come.'"></p>';
		echo '<p><strong>GoogleMap作製フォーム</strong></p><p>物件の住所を経度、緯度で指定することで、自動でgooglemapを作ります。経度緯度は<a href="http://www.geocoding.jp/" target="_blank">コチラのサイト</a>を利用してお調べください。半角英数字のみ反映されます。</p><p>経度：<input type="text" size="50" name="keid" value="'.$keid.'">半角英数字<a href="http://www.geocoding.jp/" target="_blank">住所から経度緯度を調べる</a></p>';
			echo '<p>緯度：<input type="text" size="50" name="ido" value="'.$ido.'">半角英数字</p>';
	}
	add_action('save_post','menu_meta_update');
function menu_meta_update($post_id){
	if(!wp_verify_nonce($_POST['menu_meta_nonce'],'menu_meta'))
	return $post_id;
	
	if(defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
	return $post_id;
	if('realestate' == $_POST['post_type']){
	if(!current_user_can('edit_post',$post_id))
	return $post_id ;
	}
	else{return $post_id ;}
	
	$price = $_POST['price'];
	if($price ==''){
		delete_post_meta($post_id,'price');
		}
	else{
		update_post_meta($post_id,'price',$price);
		}
		
		
		$madori = $_POST['madori'];
	if($madori ==''){
		delete_post_meta($post_id,'madori');
		}
	else{
		update_post_meta($post_id,'madori',$madori);
		}
		
		$sikikin = $_POST['sikikin'];
	if($sikikin ==''){
		delete_post_meta($post_id,'sikikin');
		}
	else{
		update_post_meta($post_id,'sikikin',$sikikin);
		}
		
		$reikin = $_POST['reikin'];
	if($reikin ==''){
		delete_post_meta($post_id,'reikin');
		}
	else{
		update_post_meta($post_id,'reikin',$reikin);
		}
		
			$menseki = $_POST['menseki'];
	if($menseki ==''){
		delete_post_meta($post_id,'menseki');
		}
	else{
		update_post_meta($post_id,'menseki',$menseki);
		}
		
			$park = $_POST['park'];
	if($park ==''){
		delete_post_meta($post_id,'park');
		}
	else{
		update_post_meta($post_id,'park',$park);
		}
		
		
		$address = $_POST['address'];
	if($address ==''){
		delete_post_meta($post_id,'address');
		}
	else{
		update_post_meta($post_id,'address',$address);
		}
		
				$setubi = $_POST['setubi'];
	if($setubi ==''){
		delete_post_meta($post_id,'setubi');
		}
	else{
		update_post_meta($post_id,'setubi',$setubi);
		}
		
	$come = $_POST['come'];
	if($come ==''){
		delete_post_meta($post_id,'come');
		}
	else{
		update_post_meta($post_id,'come',$come);
		}
		
		$keid = $_POST['keid'];
	if($keid ==''){
		delete_post_meta($post_id,'keid');
		}
	else{
		update_post_meta($post_id,'keid',$keid);
		}
		
		$ido = $_POST['ido'];
	if($ido==''){
		delete_post_meta($post_id,'ido');
		}
	else{
		update_post_meta($post_id,'ido',$ido);
		}
	
}

/*タグクラウドカスタマイズ*/
function my_tag_cloud_filter( $args = array() ){
	$args['unit']     = '%';    // smallest・largest の値の単位
	$args['smallest'] = 80;     // 最小文字サイズは 80%
	$args['largest']  = 150;    // 最大文字サイズは 150%
	$args['number']   = 30;     // 一度に表示するのは30タグまで
	$args['order']    = 'RAND'; // 表示順はランダムで
	return $args;
}
add_filter('widget_tag_cloud_args', 'my_tag_cloud_filter');

/*テーブル生成*/

function make_table_news(){
	?><div class="image_gan">
<a href="<?php the_permalink(); ?>">
<?php the_post_thumbnail('thumbnail'); ?>
</a>
</div><div class="contentgun_single">

    <table style="width:90%;">
    <tr>
    <td>住所：</td><td><?php echo(get_post_meta(get_the_ID(),'address',true));?></td>
    </tr>
    <tr>
    <td>賃料：</td><td>￥<?php echo number_format((get_post_meta(get_the_ID(),'price',true)));?></td>
    </tr>
    <tr>
    <td>敷金：</td><td><?php echo(get_post_meta(get_the_ID(),'sikikin',true));?></td>
    </tr>
    <tr>
    <td>礼金：</td><td><?php echo(get_post_meta(get_the_ID(),'reikin',true));?></td>
    </tr>
    <tr>
    <td>間取り：</td><td><?php  echo(get_post_meta(get_the_ID(),'madori',true)); ?></td>
    </tr>
    <tr>
    <td>面積：</td><td><?php echo(get_post_meta(get_the_ID(),'menseki',true));?></td>
    </tr>
    <tr>
    <td>駐車場：</td><td><?php echo(get_post_meta(get_the_ID(),'park',true));?></td>
    </tr>
    <tr>
    <td>設備：</td><td><?php echo(get_post_meta(get_the_ID(),'setubi',true));?></td>
    </tr>
    </table>
  
</div><!--end contentgun-->
<div class="clear"></div>
	<?php
	}

function category_tree_list($parent_id=0){
	$cats=get_categories(array(
	'parent'=>$parent_id,
	'hide_empty'=>0,
	));
	
	if(count($cats)){
		echo "<ul>\n";
		foreach($cats as $cat){
			echo '<li><a href="'.get_category_link($cat->term_id).'">'.$cat->name.'</a>('.$cat->count.")\n";
			category_tree_list($cat->term_id);
			echo"</li>\n";
			}
echo"</ul>\n";		}
	
	}
	
/*パンくずリスト*/

function bread_list(){
	 global $wp_query; $total_results=$wp_query->found_posts;
	 if(!is_home()): ?>
<div id="breadcrumb">
<ul>
	<li><a href="<?php echo home_url(); ?>/">HOME</a></li>
	<li>&gt;</li>
<?php if(is_search()): /* 検索結果表示 */ ?>
<li>[<?php the_search_query(); ?>]で検索した結果<?php echo $total_results; ?>件がヒットしました。

</li>
<?php elseif(is_tag()): /* タグアーカイブ */?>
<?php single_tag_title(); ?>
<?php elseif(is_404()): /* 404 Not Found */?>
<li>404 Not Found</li> 
<?php elseif(is_date()): /* 日付アーカイブ */?>
<?php if(is_day()):  /*日別アーカイブ*/ ?> 
<li><a href="<?php echo get_year_link(get_query_var('year')); ?>"><?php echo get_query_var('year'); ?>年</a></li>
<li>&gt;</li>
<li><a href="<?php echo get_month_link(get_query_var('year'), get_query_var('monthnum')); ?>"><?php echo get_query_var('monthnum'); ?>月</a></li>
<li>&gt;</li>
<li><?php echo get_query_var('day'); ?>日</li>
<?php elseif(is_month()): /*月別アーカイブ*/?>
<li><a href="<?php echo get_year_link(get_query_var('year')); ?>"><?php echo get_query_var('year'); ?>年</a></li>
		<li>&gt;</li>
		<li><?php echo get_query_var('monthnum'); ?>月</li>
<?php elseif(is_year()): /*年別アーカイブ*/?>
<li><?php echo get_query_var('year'); ?>年</li>
<?php endif; ?>

<?php elseif(is_category()): /* カテゴリーアーカイブ */?>
		<?php $cat = get_queried_object(); ?>
<?php if($cat -> parent != 0): ?>
<?php $ancestors = array_reverse(get_ancestors( $cat -> cat_ID, 'category' )); ?>
<?php endif; ?>
	<li><?php //echo $cat -> cat_name; ?></li>
<?php elseif(is_author()): /* 投稿者アーカイブ */?>

<?php elseif(is_page()): /* 固定ページ */?>
<?php if($post -> post_parent != 0 ): /* 親ページの有無 */ ?>
<?php $ancestors = array_reverse( $post-> ancestors ); /* 祖先ページの ID を取得 */ ?>
<?php foreach($ancestors as $ancestor): /* 祖先ページの数だけ繰り返し処理 */ ?>
<li><a href="<?php echo get_permalink($ancestor); ?>"><?php echo get_the_title($ancestor); ?></a></li>
	<li>&gt;</li>
<?php endforeach; ?>
<?php endif; ?>


<?php elseif(is_attachment()): /* 添付ファイルページ */?>
<?php if($post->post_parent !=0): ?>
<li><a href="<?php echo get_permalink($post->post_parent); ?>"><?php echo get_the_title($post->post_parent); ?></a></li>
<li>&gt;</li>
<?php endif; ?>
<li><?php echo $post -> post_title; ?></li>

<?php elseif(is_single()): /* ブログ記事 */?>
<?php $categories = get_the_category($post->ID); /* カテゴリーを取得 */ ?>
<?php $cat = $categories[0]; /* 配列から最初のカテゴリーを取得 */ ?>
<?php @$tagbort1=array_reverse(get_the_terms($post->ID,'area',true));?>
<?php @$tagbort2=array_reverse(get_the_terms($post->ID,'layout',true)); ?>
<?php @$tagbort3=array_reverse(get_the_terms($post->ID,'prtag',true));?>
<?php if($cat -> parent != 0): /* 親カテゴリーの有無 */ ?>
<?php $ancestors = array_reverse(get_ancestors( $cat -> cat_ID, 'category' )); /* 祖先カテゴリーを取得 */?>
<?php foreach($ancestors as $ancestor): ?>
<li><a href="<?php echo get_category_link($ancestor); ?>"><?php echo get_cat_name($ancestor); ?></a></li>
<li>&gt;</li>
<?php endforeach; ?>
<?php endif; ?>
<li><a href="<?php echo get_category_link($cat -> cat_ID); ?>"><?php echo $cat-> cat_name; ?></a></li>
<?php  endif; ?>
<?php if($tagbort1!=""):
foreach($tagbort1 as $tagbort):?>
<a href="<?php echo get_term_link($tagbort,'area'); ?>">
<?php echo $tagbort->name; ?>
</a> <li>&gt;</li><?php endforeach; ?>
<li>&gt;</li>
<li><?php echo single_post_title(); ?></li>

<?php elseif(is_tax('area')): /* タグアーカイブ */?>
<?php $tagbort1=@array_reverse(get_the_terms($post->ID,'area'));
if($tagbort1!=""):
foreach($tagbort1 as $tagbort):?>
<a href="<?php echo get_term_link($tagbort,'area'); ?>">
<?php echo $tagbort->name; ?>
</a><li>&gt;</li>
<?php  endforeach; endif;
 ?>
<?php elseif(is_tax('layout')): /* タグアーカイブ */?>
<?php $tagbort2=array_reverse(get_the_terms($post->ID,'layout')); 
if($tagbort2!=""):
foreach($tagbort2 as $tagbort):?>
<a href="<?php echo get_term_link($tagbort,'layout'); ?>">
<?php echo $tagbort->name; ?>
</a><li>&gt;</li>
<?php endforeach; endif;
?>
<?php elseif(is_tax('prtag')): /* タグアーカイブ */?>
<?php @$tagbort3=array_reverse(get_the_terms($post->ID,'prtag')); 
if($tagbort3!=""):
foreach($tagbort3 as $tagbort):?>
<a href="<?php echo get_term_link($tagbort,'prtag'); ?>">
<?php echo $tagbort->name; ?>
</a><li>&gt;</li>
<?php endforeach; endif;
?>
<?php else: /* 上記以外 */?>
 <li><?php wp_title('', true); ?></li>

<?php endif; ?>
</ul>
</div>
<?php endif; 
	
	}

//検索からブログ除外
function search_filter($query) {
	@$deleteid=get_cat_ID( "ブログ" );
  if (!$query -> is_admin && $query -> is_search) {
    $query -> set('category__not_in', array($deleteid));
  }
  return $query;
}
add_filter('pre_get_posts', 'search_filter');

//ページング
function pagination($pages = '', $range = 4)
{
     $showitems = ($range * 2)+1; 
 
     global $paged;//複数ページのページ番号
	 //カテゴリーやタグ一覧ページなど、複数に分割されているページにおいて、そのページ番号となる。
     if(empty($paged)) $paged = 1;
 
     if($pages == '')
     {
         global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
     }  
 
     if(1 != $pages)
     {
         echo "<div class=\"pagenavgat\"><span>Page ".$paged." of ".$pages."</span>";
         if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<a href='".get_pagenum_link(1)."'>« First</a>";//get_pagenum_link(0);だとエスケープされてしまう。
         if($paged > 1 && $showitems < $pages) echo "<a href='".get_pagenum_link($paged - 1)."'>‹ Previous</a>";
 
         for ($i=1; $i <= $pages; $i++)
         {
             if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
             {
                 echo ($paged == $i)? "<span class=\"current\">".$i."</span>":"<a href='".get_pagenum_link($i)."' class=\"inactive\">".$i."</a>";
             }
         }
 
         if ($paged < $pages && $showitems < $pages) echo "<a href=\"".get_pagenum_link($paged + 1)."\">Next ›</a>";
         if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($pages)."'>Last »</a>";
         echo "</div>\n";
     }
}



//sitemap用

function simple_sitemap(){
	echo '<div id="sitemap">';
	
 if(query_posts('post_type=drink')!=false):
@wp_list_categories(array('title_li'=>'','taxonomy'=>'drinkct','hide_empty'=>1,'show_count'=>1,));
endif;

if(query_posts('post_type=food')!=false):
@wp_list_categories(array('title_li'=>'','taxonomy'=>'foodct','hide_empty'=>1,'show_count'=>1,));
endif;

if(query_posts('post_type=sweets')!=false):
@wp_list_categories(array('title_li'=>'','taxonomy'=>'sweetsct','hide_empty'=>1,'show_count'=>1,));
endif;

if(query_posts('post_type=beer')!=false):
@wp_list_categories(array('title_li'=>'','taxonomy'=>'beerct','hide_empty'=>1,'show_count'=>1,));
endif; 
	
	global $wpdb;
	$args = array('depth'        => 0,
		'show_date'    => NULL,
		'date_format'  => get_option('date_format'),
		'child_of'     => 0,
		'exclude'      => NULL,
		'include'      => NULL,
		'title_li'           => '',
		'echo'         => 1,
		'authors'      => NULL,
		'sort_column'  => 'menu_order, post_title',
		'link_before'  => NULL,
		'link_after'   => NULL,
		'exclude_tree' => NULL ); 

	echo '<hr><ul>';
		wp_list_pages($args);
	echo '</ul><hr>';

	$args = array('show_option_all'    => NULL,
		'orderby'            => 'name',
		'order'              => 'ASC',
		'show_last_update'   => 0,
		'style'              => 'list',
		'show_count'         => 0,
		'hide_empty'         => 1,
		'use_desc_for_title' => 1,
		'child_of'           => 0,
		'feed'               => NULL,
		'feed_type'          => NULL,
		'feed_image'         => NULL,
		'exclude'            => NULL,
		'exclude_tree'       => NULL,
		'include'            => NULL,
		'hierarchical'       => true,
		'title_li'           => '',
		'number'             => NULL,
		'echo'               => 1,
		'depth'              => 0,
		'current_category'   => 0,
		'pad_counts'         => 0,
		'taxonomy'           => 'category',
		'walker'             => 'Walker_Category' );

        echo '<ul>';
	   echo wp_list_categories( $args );
	   echo '</ul>';
	echo '</div>';
}
add_shortcode('sitemap', 'simple_sitemap');